import json

import pytest

from tests.rest import rest_tools
from tests.rest.rest_tools import get_user_credentials, get_user_secret


@pytest.fixture
def student_credentials() -> str:
    return get_user_credentials('student1')


@pytest.fixture
def teacher_credentials() -> str:
    return get_user_credentials('teacher2', '123123')


@pytest.fixture
def teacher_secret() -> str:
    return get_user_secret('teacher1', 'ultimate_teacher_secret')


def test_project_detail_using_admin_cred(client):
    path = f'/courses/testcourse1'
    response = rest_tools.make_request(client, path, 'get')
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_student_cred(client, student_credentials):
    path = f'/courses/testcourse1'
    response = rest_tools.make_request(
        client, path, 'get', credentials=student_credentials)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_teacher_cred(client, teacher_credentials):
    path = f'/courses/testcourse1/projects'
    response = rest_tools.make_request(
        client, path, 'get', credentials=teacher_credentials)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'


def test_project_detail_using_teacher_secret(client, teacher_secret):
    path = f'/courses/testcourse1'
    response = rest_tools.make_request(
        client, path, 'get', credentials=teacher_secret)
    assert response.status_code == 200
    assert response.mimetype == 'application/json'
